@@ -50,10 +50,13 @@ pub async fn wasm_split(
     self::emit::emit_modules(
         &module,
         &mut split_program_info,
-        |identifier: &SplitModuleIdentifier, data: &[u8], hash: &str| -> Result<()> {
-            let output_path = match identifier {
-                SplitModuleIdentifier::Main => proj.lib.wasm_file.source.clone(),
-                _ => dest_dir.join(format!("{name}.{hash}.wasm", name = identifier.name(proj))),
+        |identifier: &SplitModuleIdentifier, data: &[u8]| -> Result<()> {
+            let output_path = if matches!(identifier, SplitModuleIdentifier::Main) {
+                let mut source = proj.lib.wasm_file.source.clone();
+                source.set_file_name(format!("{}_split.wasm", source.file_stem().unwrap()));
+                source
+            } else {
+                dest_dir.join(format!("{}.wasm", identifier.hash(proj)))
             };
 
             std::fs::write(&output_path, data)?;
@@ -115,49 +118,43 @@ function makeLoad(url, deps) {
     );
     let mut split_deps = HashMap::<String, Vec<String>>::new();
     let mut manifest = HashMap::<String, Vec<String>>::new();
-    for (name, _) in split_program_info.output_modules.iter() {
-        let SplitModuleIdentifier::Chunk { splits, .. } = name else {
+    for (identifier, _) in split_program_info.output_modules.iter() {
+        let SplitModuleIdentifier::Chunk { splits, hash } = identifier else {
             continue;
         };
-        let chunk_name = name.name(proj);
-        let chunk_name_hashed = name.name_hashed(proj);
-        let chunk_name_sanitized = chunk_name_hashed.replace(['.', '-'], "_");
+        let name = identifier.name(proj);
 
-        manifest
-            .entry(chunk_name)
-            .or_default()
-            .push(chunk_name_hashed.clone());
+        manifest.entry(name.clone()).or_default().push(hash.clone());
 
         for split in splits {
             split_deps
                 .entry(split.clone())
                 .or_default()
-                .push(chunk_name_sanitized.clone());
+                .push(name.clone());
             manifest
                 .entry(split.clone())
                 .or_default()
-                .push(chunk_name_hashed.clone());
+                .push(hash.clone());
         }
 
         javascript.push_str(
             format!(
-                "const __wasm_split_load_{chunk_name_sanitized} = makeLoad(new URL(\"./{chunk_name_hashed}.wasm\", import.meta.url), []);\n",
+                "const __wasm_split_load_{name} = makeLoad(new URL(\"./{hash}.wasm\", import.meta.url), []);\n",
             ).as_str()
         );
     }
     for (identifier, _) in split_program_info.output_modules.iter().rev() {
-        let SplitModuleIdentifier::Split { name, .. } = identifier else {
+        let SplitModuleIdentifier::Split { name, hash } = identifier else {
             continue;
         };
-        let name_hashed = identifier.name_hashed(proj);
 
         manifest
             .entry(identifier.name(proj))
             .or_default()
-            .push(name_hashed.clone());
+            .push(hash.clone());
 
         javascript.push_str(format!(
-            "export const __wasm_split_load_{name} = makeLoad(new URL(\"./{name_hashed}.wasm\", import.meta.url), [{deps}]);\n",
+            "export const __wasm_split_load_{name} = makeLoad(new URL(\"./{hash}.wasm\", import.meta.url), [{deps}]);\n",
             deps = split_deps
             .remove(name)
             .unwrap_or_default()
